Index: src/x64/lithium-codegen-x64.cc |
diff --git a/src/x64/lithium-codegen-x64.cc b/src/x64/lithium-codegen-x64.cc |
index 72091c3e4d371e6258e83317f2177b306c25cab3..7c805bfedadc60e83bf862de1dfb401e0c5cf6de 100644 |
--- a/src/x64/lithium-codegen-x64.cc |
+++ b/src/x64/lithium-codegen-x64.cc |
@@ -154,10 +154,10 @@ bool LCodeGen::GeneratePrologue() { |
} |
#endif |
// Classic mode functions need to replace the receiver with the global proxy |
// when called as functions (without an explicit receiver object). |
if (info_->this_has_uses() && |
- info_->is_classic_mode() && |
+ info_->is_sloppy_mode() && |
!info_->is_native()) { |
Label ok; |
StackArgumentsAccessor args(rsp, scope()->num_parameters()); |
@@ -2943,7 +2943,7 @@ void LCodeGen::DoLoadKeyedExternalArray(LLoadKeyed* instr) { |
case FAST_HOLEY_SMI_ELEMENTS: |
case FAST_HOLEY_DOUBLE_ELEMENTS: |
case DICTIONARY_ELEMENTS: |
- case NON_STRICT_ARGUMENTS_ELEMENTS: |
+ case SLOPPY_ARGUMENTS_ELEMENTS: |
UNREACHABLE(); |
break; |
} |
@@ -4132,7 +4132,7 @@ void LCodeGen::DoStoreKeyedExternalArray(LStoreKeyed* instr) { |
case FAST_HOLEY_SMI_ELEMENTS: |
case FAST_HOLEY_DOUBLE_ELEMENTS: |
case DICTIONARY_ELEMENTS: |
- case NON_STRICT_ARGUMENTS_ELEMENTS: |
+ case SLOPPY_ARGUMENTS_ELEMENTS: |
UNREACHABLE(); |
break; |
} |
@@ -154,10 +154,10 @@ bool LCodeGen::GeneratePrologue() { |
} |
#endif |
- // Classic mode functions need to replace the receiver with the global proxy |
+ // Sloppy mode functions need to replace the receiver with the global proxy |
// when called as functions (without an explicit receiver object). |
if (info_->this_has_uses() && |